summaryrefslogtreecommitdiff
path: root/noncore/settings/networksettings2/activatevpn.cpp
authorwimpie <wimpie>2005-01-11 21:42:31 (UTC)
committer wimpie <wimpie>2005-01-11 21:42:31 (UTC)
commit96678694f8952f60d0a895cede2b621404b4bfb8 (patch) (side-by-side diff)
tree7138e554e5ba200b8f9ca8b51c89b47531dc34f2 /noncore/settings/networksettings2/activatevpn.cpp
parentf89120a7a1a3d0bf9c0805456490906ca914e560 (diff)
downloadopie-96678694f8952f60d0a895cede2b621404b4bfb8.zip
opie-96678694f8952f60d0a895cede2b621404b4bfb8.tar.gz
opie-96678694f8952f60d0a895cede2b621404b4bfb8.tar.bz2
Major rename of NodeCollection to NetworkSetup
this commit is broken (missing symbols)
Diffstat (limited to 'noncore/settings/networksettings2/activatevpn.cpp') (more/less context) (show whitespace changes)
-rw-r--r--noncore/settings/networksettings2/activatevpn.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/noncore/settings/networksettings2/activatevpn.cpp b/noncore/settings/networksettings2/activatevpn.cpp
index 768a031..35a881b 100644
--- a/noncore/settings/networksettings2/activatevpn.cpp
+++ b/noncore/settings/networksettings2/activatevpn.cpp
@@ -4,32 +4,32 @@
#include "activatevpn.h"
class MyCheckListItem : public QCheckListItem {
public :
- MyCheckListItem( NodeCollection * N, QListView * V );
+ MyCheckListItem( NetworkSetup * N, QListView * V );
- NodeCollection * NC;
+ NetworkSetup * NC;
};
-MyCheckListItem::MyCheckListItem( NodeCollection * N, QListView * V ):
+MyCheckListItem::MyCheckListItem( NetworkSetup * N, QListView * V ):
QCheckListItem( V, N->name() ) {
NC = N;
}
ActivateVPN::ActivateVPN( const QString & I ) :
ActivateVPNGUI( 0, 0, TRUE ), NSD() {
QCheckListItem * CI;
VPN_LV->clear();
VPN_LV->header()->hide();
- // find all connections that want to be triggered by this interface
- for( QDictIterator<NodeCollection> it(NSResources->connections());
+ // find all NetworkSetups that want to be triggered by this interface
+ for( QDictIterator<NetworkSetup> it(NSResources->networkSetups());
it.current();
++it ) {
if( it.current()->triggeredBy( I ) ) {
CI = new MyCheckListItem( it.current(), VPN_LV );
}
}